@@ -9,7 +9,9 @@ It also provides two methods:
 """
 
 import importlib
+import warnings
 from abc import ABC, abstractmethod
+from contextlib import suppress
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, Optional, Sequence
 from xml.etree.ElementTree import Element, tostring
@@ -23,14 +25,13 @@ from mkdocstrings.handlers.rendering import (
     Highlighter,
     IdPrependingTreeprocessor,
     MkdocstringsInnerExtension,
+    ParagraphStrippingTreeprocessor,
 )
 from mkdocstrings.inventory import Inventory
 from mkdocstrings.loggers import get_template_logger
 
 CollectorItem = Any
 
-TEMPLATES_DIR = Path(__file__).parent.parent / "templates"
-
 
 class CollectionError(Exception):
     """An exception raised when some collection of data failed."""
@@ -73,24 +74,33 @@ class BaseRenderer(ABC):
     fallback_theme: str = ""
     extra_css = ""
 
-    def __init__(self, directory: str, theme: str, custom_templates: Optional[str] = None) -> None:
+    def __init__(self, handler: str, theme: str, custom_templates: Optional[str] = None, directory: str = None) -> None:
         """Initialize the object.
 
         If the given theme is not supported (it does not exist), it will look for a `fallback_theme` attribute
         in `self` to use as a fallback theme.
 
         Arguments:
-            directory: The name of the directory containing the themes for this renderer.
+            handler: The name of the handler.
             theme: The name of theme to use.
             custom_templates: Directory containing custom templates.
+            directory: Deprecated and renamed as `handler`.
         """
+        # TODO: remove at some point
+        if directory:
+            warnings.warn(
+                "The 'directory' keyword parameter is deprecated and renamed 'handler'. ",
+                DeprecationWarning,
+            )
+            if not handler:
+                handler = directory
+
         paths = []
 
-        themes_dir = TEMPLATES_DIR / directory
-
+        themes_dir = self.get_templates_dir(handler)
         paths.append(themes_dir / theme)
 
-        if self.fallback_theme:
+        if self.fallback_theme and self.fallback_theme != theme:
             paths.append(themes_dir / self.fallback_theme)
 
         for path in paths:
@@ -100,7 +110,7 @@ class BaseRenderer(ABC):
                 break
 
         if custom_templates is not None:
-            paths.insert(0, Path(custom_templates) / directory / theme)
+            paths.insert(0, Path(custom_templates) / handler / theme)
 
         self.env = Environment(
             autoescape=True,
@@ -125,6 +135,53 @@ class BaseRenderer(ABC):
             The rendered template as HTML.
         """  # noqa: DAR202 (excess return section)
 
+    def get_templates_dir(self, handler: str) -> Path:
+        """Return the path to the handler's templates directory.
+
+        Override to customize how the templates directory is found.
+
+        Arguments:
+            handler: The name of the handler to get the templates directory of.
+
+        Raises:
+            FileNotFoundError: When the templates directory cannot be found.
+
+        Returns:
+            The templates directory path.
+        """
+        # Templates can be found in 2 different logical locations:
+        # - in mkdocstrings_handlers/HANDLER/templates: our new migration target
+        # - in mkdocstrings/templates/HANDLER: current situation, this should be avoided
+        # These two other locations are forbidden:
+        # - in mkdocstrings_handlers/templates/HANDLER: sub-namespace packages are too annoying to deal with
+        # - in mkdocstrings/handlers/HANDLER/templates: not currently supported,
+        #   and mkdocstrings will stop being a namespace
+
+        with suppress(ModuleNotFoundError):  # TODO: catch at some point to warn about missing handlers
+            import mkdocstrings_handlers
+
+            for path in mkdocstrings_handlers.__path__:  # noqa: WPS609
+                theme_path = Path(path, handler, "templates")
+                if theme_path.exists():
+                    return theme_path
+
+        # TODO: remove import and loop at some point,
+        # as mkdocstrings will stop being a namespace package
+        import mkdocstrings
+
+        for path in mkdocstrings.__path__:  # noqa: WPS609,WPS440
+            theme_path = Path(path, "templates", handler)
+            if theme_path.exists():
+                if handler != "python":
+                    warnings.warn(
+                        "Exposing templates in the mkdocstrings.templates namespace is deprecated. "
+                        "Put them in a templates folder inside your handler package instead.",
+                        DeprecationWarning,
+                    )
+                return theme_path
+
+        raise FileNotFoundError(f"Can't find 'templates' folder for handler '{handler}'")
+
     def get_anchors(self, data: CollectorItem) -> Sequence[str]:
         """Return the possible identifiers (HTML anchors) for a collected item.
 
@@ -140,13 +197,16 @@ class BaseRenderer(ABC):
         except AttributeError:
             return ()
 
-    def do_convert_markdown(self, text: str, heading_level: int, html_id: str = "") -> Markup:
+    def do_convert_markdown(
+        self, text: str, heading_level: int, html_id: str = "", *, strip_paragraph: bool = False
+    ) -> Markup:
         """Render Markdown text; for use inside templates.
 
         Arguments:
             text: The text to convert.
             heading_level: The base heading level to start all Markdown headings from.
             html_id: The HTML id of the element that's considered the parent of this element.
+            strip_paragraph: Whether to exclude the <p> tag from around the whole output.
 
         Returns:
             An HTML string.
@@ -154,11 +214,13 @@ class BaseRenderer(ABC):
         treeprocessors = self._md.treeprocessors
         treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = heading_level
         treeprocessors[IdPrependingTreeprocessor.name].id_prefix = html_id and html_id + "--"
+        treeprocessors[ParagraphStrippingTreeprocessor.name].strip = strip_paragraph
         try:
             return Markup(self._md.convert(text))
         finally:
             treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = 0
             treeprocessors[IdPrependingTreeprocessor.name].id_prefix = ""
+            treeprocessors[ParagraphStrippingTreeprocessor.name].strip = False
             self._md.reset()
 
     def do_heading(
@@ -179,7 +241,7 @@ class BaseRenderer(ABC):
             role: An optional role for the object bound to this heading.
             hidden: If True, only register it for the table of contents, don't render anything.
             toc_label: The title to use in the table of contents ('data-toc-label' attribute).
-            attributes: Any extra HTML attributes of the heading.
+            **attributes: Any extra HTML attributes of the heading.
 
         Returns:
             An HTML string.
@@ -397,7 +459,17 @@ class Handlers:
         if name not in self._handlers:
             if handler_config is None:
                 handler_config = self.get_handler_config(name)
-            module = importlib.import_module(f"mkdocstrings.handlers.{name}")
+            try:
+                module = importlib.import_module(f"mkdocstrings_handlers.{name}")
+            except ModuleNotFoundError:
+                module = importlib.import_module(f"mkdocstrings.handlers.{name}")
+                if name != "python":
+                    warnings.warn(
+                        DeprecationWarning(
+                            "Using the mkdocstrings.handlers namespace is deprecated. "
+                            "Handlers must now use the mkdocstrings_handlers namespace."
+                        )
+                    )
             self._handlers[name] = module.get_handler(
                 self._config["theme_name"],
                 self._config["mkdocstrings"]["custom_templates"],
