@@ -2,19 +2,23 @@
 
 import logging
 from pathlib import Path
-from typing import Any, Callable, Optional, Tuple
+from typing import Any, Callable, MutableMapping, Optional, Tuple
 
-from jinja2 import contextfunction
 from jinja2.runtime import Context
 from mkdocs.utils import warning_filter
 
+try:
+    from jinja2 import pass_context
+except ImportError:  # TODO: remove once Jinja2 < 3.1 is dropped
+    from jinja2 import contextfunction as pass_context  # noqa: WPS440
+
 TEMPLATES_DIR = Path(__file__).parent / "templates"
 
 
 class LoggerAdapter(logging.LoggerAdapter):
     """A logger adapter to prefix messages."""
 
-    def __init__(self, prefix: str, logger):
+    def __init__(self, prefix: str, logger: logging.Logger):
         """Initialize the object.
 
         Arguments:
@@ -24,7 +28,7 @@ class LoggerAdapter(logging.LoggerAdapter):
         super().__init__(logger, {})
         self.prefix = prefix
 
-    def process(self, msg: str, kwargs) -> Tuple[str, Any]:
+    def process(self, msg: str, kwargs: MutableMapping[str, Any]) -> Tuple[str, Any]:
         """Process the message.
 
         Arguments:
@@ -71,7 +75,7 @@ def get_template_logger_function(logger_func: Callable) -> Callable:
         A function.
     """
 
-    @contextfunction
+    @pass_context
     def wrapper(context: Context, msg: Optional[str] = None) -> str:
         """Log a message.
 
@@ -118,7 +122,7 @@ def get_logger(name: str) -> LoggerAdapter:
     """
     logger = logging.getLogger(f"mkdocs.plugins.{name}")
     logger.addFilter(warning_filter)
-    return LoggerAdapter(name, logger)
+    return LoggerAdapter(name.split(".", 1)[0], logger)
 
 
 def get_template_logger() -> TemplateLogger:
