@@ -6,11 +6,6 @@ from textwrap import dedent
 import pytest
 
 
-def test_render_html_escaped_sequences(ext_markdown):
-    """Assert HTML-escaped sequences are correctly parsed as XML."""
-    ext_markdown.convert("::: tests.fixtures.html_escaped_sequences")
-
-
 @pytest.mark.parametrize("ext_markdown", [{"markdown_extensions": [{"footnotes": {}}]}], indirect=["ext_markdown"])
 def test_multiple_footnotes(ext_markdown):
     """Assert footnotes don't get added to subsequent docstrings."""
@@ -66,8 +61,8 @@ def test_quote_inside_annotation(ext_markdown):
 
 def test_html_inside_heading(ext_markdown):
     """Assert that headings don't double-escape HTML."""
-    output = ext_markdown.convert("::: tests.fixtures.builtin")
-    assert "=&lt;" in output
+    output = ext_markdown.convert("::: tests.fixtures.html_tokens")
+    assert "&#39;&lt;" in output
     assert "&amp;" not in output
 
 
